#include <windows.h>
#include <math.h>

typedef struct VECTOR3  {

	float x,y,z;
    VECTOR3() {};
    VECTOR3( FLOAT nx, FLOAT ny, FLOAT nz ):x(nx),y(ny),z(nz) {}; 

    // assignment operators
    VECTOR3& operator += ( CONST VECTOR3& r) {x+=r.x;y+=r.y;z+=r.z; return *this;};
    VECTOR3& operator -= ( CONST VECTOR3& r) {x-=r.x;y-=r.y;z-=r.z; return *this;};
    VECTOR3& operator *= ( FLOAT val) { x*=val;y*=val;z*=val; return *this;};
    VECTOR3& operator /= ( FLOAT val) { val=1.0f/val;x*=val;y*=val;z*=val; return *this;}
	
	// operations	
	void  Normalize();
	float DotProduct(VECTOR3& vec);
	void  CrossProduct(VECTOR3& vecA, VECTOR3& vecB);
} VECTOR3, *LPVECTOR3;

inline void VECTOR3::Normalize()
{
    float denom = 1.0f / sqrt(x * x + y * y + z * z);

    x *= denom;
    y *= denom;
    z *= denom;
}

inline float VECTOR3::DotProduct(VECTOR3& vec)
{
    return x * vec.x + y * vec.y + z * vec.z;
}

inline void VECTOR3::CrossProduct(VECTOR3& vecA, VECTOR3& vecB)
{
    x = vecA.y * vecB.z - vecA.z * vecB.y;
    y = vecA.z * vecB.x - vecA.x * vecB.z;
    z = vecA.x * vecB.y - vecA.y * vecB.x;
}